summaryrefslogtreecommitdiff
path: root/kvm.c
diff options
context:
space:
mode:
authorBryan Cantrill <bryan@joyent.com>2011-06-02 22:10:24 -0700
committerBryan Cantrill <bryan@joyent.com>2011-06-02 22:10:24 -0700
commit07b961b34ba5c771b43d22b211f09a90fdb0859c (patch)
treebaaa0c448f73ffca83aecc20eb01871208a292a6 /kvm.c
parent76c584bb86bcd0398f38cc3653c49412a65dd640 (diff)
downloadillumos-kvm-07b961b34ba5c771b43d22b211f09a90fdb0859c.tar.gz
HVM-271 kicking a VCPU should poke (not cross-call) a remote CPU
Diffstat (limited to 'kvm.c')
-rw-r--r--kvm.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/kvm.c b/kvm.c
index 4df32c4..6cb9353 100644
--- a/kvm.c
+++ b/kvm.c
@@ -6363,11 +6363,11 @@ kvm_vcpu_kick(struct kvm_vcpu *vcpu)
if (cpu != CPU->cpu_id && cpu != -1) {
if (!test_and_set_bit(KVM_REQ_KICK, &vcpu->requests)) {
/*
* If we haven't already kicked this VCPU, we'll send
* an empty cross call to the CPU on which it's
* running. (This will serve to induce a VM exit.)
*/
- kvm_xcall(cpu, NULL, NULL);
+ poke_cpu(cpu);
}
}
}
@@ -6363,11 +6363,11 @@ kvm_vcpu_kick(struct kvm_vcpu *vcpu)
if (!test_and_set_bit(KVM_REQ_KICK, &vcpu->requests)) {
/*
- * If we haven't already kicked this VCPU, we'll send
- * an empty cross call to the CPU on which it's
- * running. (This will serve to induce a VM exit.)
+ * If we haven't already kicked this VCPU, we'll poke
+ * the the CPU on which it's running. (This will serve
+ * to induce a VM exit.)
*/